#!/bin/sh

# buildVis.sh - build VisClient for different arches and drop them into the webroot or $webdir/release_candidates
# quick hack to build zip files
#
# USE AT YOUR OWN RISK !!1!

# usage:
# BUILDTYPE={RC,RELEASE} [debug=1] buildVis.sh [-r revision]

umask 002

sys=`uname -s`
case $sys in
	Linux)
	webdir="/data/www/vis"
	;;
	Darwin)
	echo "$sys ? you've entered unknown terrain, ymmv."
	echo "it might be an idea to compile on a case-sensitive fs."
	webdir="/Library/WebServer/Documents/vis"
	;;
	*)
	echo "building on $sys is not yet supported."
	exit
	;;
esac

COMPILEDIR=`pwd`
BASTELDIR=`mktemp -d /tmp/buildVisClient.XXXX`
[ $? != 0 ] && exit
arches="Linux32 Linux64 Windows MacOSX"
rcdir="release_candidates"
excludes='*native/* *native *dist/* *dist *misc/* *misc *.svn* *.java'
osxapp="VisClient.app"
osxappcontents="Contents/Resources/Java"
OSXFOO=$BASTELDIR/$osxapp/$osxappcontents
upstream=vis.hfbk.net
domain=hfbk.net
crew=vis
hostname=`hostname -f`

case "$BUILDTYPE" in
		RC)
		webdir="$webdir/$rcdir"
		;;
		RELEASE)
		;;
		*)
cat << EOT

SOTP ! safety net engaged. BUILDTYPE _MUST_ be set to either RC or RELEASE

to make a release candidate, or, respectively, a full release, use

make rc
or
make release

instead.

to just locally build the software, 'make' is enough.

make help
lists other targets as well.

build aborted.

EOT
		exit
		;;
esac

if [ -z "$*" ] ; then
		echo "no version (-r) specified, using trunk"
else
		release=$*
fi


if [ "$debug" ] ; then
		RM=echo
else
		RM=rm
fi

$RM -f $webdir/VisClient*.zip

cd $COMPILEDIR || {
		echo "wtf.............."  
	   	exit
} 

echo "generating version File .."
$RM -f $COMPILEDIR/version.txt
svn info | awk '/Revision:/ {print $2}' > $COMPILEDIR/version.txt
version=`cat $COMPILEDIR/version.txt`
echo "r$version"
$RM -f dist/*

echo "compiling..."
make
echo "done."

echo "packaging for: $arches"
[ ! -d dist ] && mkdir -p dist
[ ! -d "$webdir" ] && mkdir -p $webdir

make_dist(){
		echo "building files to $webdir"
		for arch in $arches ; do
				echo "building $arch"
				case $arch in MacOSX)
					co=`pwd`
					mkdir -p $OSXFOO
					# /tmp
					# FIXME, this is horrible
					cp -a `ls -1 | grep -v native` $OSXFOO
					cp native/VisClient${arch}.zip $BASTELDIR
					cd $BASTELDIR
					cp $co/Info.plist $osxapp/Contents
					perl -pi -le "s/VIS_SVN_REVISION/$version/g" $osxapp/Contents/Info.plist
					zip -yrq VisClient${arch}.zip VisClient.app
					zip -drq VisClient${arch}.zip $excludes
					ls -l VisClient${arch}.zip
					cmd="cp VisClient${arch}.zip $webdir/"
					$cmd || sudo $cmd
					cd $co
					cp $BASTELDIR/VisClient${arch}.zip dist/VisClient${arch}-r${version}.zip
					;;
				*)
					cp native/VisClient${arch}.jar dist
					zip -yrq dist/VisClient${arch}.jar .
					zip -drq dist/VisClient${arch}.jar $excludes
					ls -l dist/VisClient${arch}.jar
					cmd="cp dist/VisClient${arch}.jar $webdir/"
					$cmd || sudo $cmd
					;;
				esac
		done
		cmd="cp $COMPILEDIR/version.txt $webdir"
		$cmd || sudo $cmd
		if test "$BUILDTYPE" = "RC"  && test "$hostname" = "$upstream" ; then
				(	echo "version $version" 
					ls -l $webdir 
					echo "download: http://$upstream/vis/$rcdir" 
					svn log -r $version
			   	) | mail -s "new vis rc r$version" $crew@$domain
		else	(	cd $COMPILEDIR
					echo "version $version" 
					ls -l $webdir 
					echo "download: http://$upstream/vis/$rcdir" 
					svn log -r $version
				)
		fi
}

make_dist && echo "all targets compiled and copied into $webdir." || {
	echo "somethings wrong with the jars"
	exit
	}

rm -rf $BASTELDIR

